#!/bin/bash
# Sync Repo Script
# @Author: Paul Bernal <paul.bernal@cedia.org.ec>
# @Licence: WTFPL

BASEPATH="/var/www/mirror"

# Functions Section
usage() {
  echo "Usage: $0 <distroname>"
}

log() {
    NOW=$(date)
    echo "${NOW} ${USER} $1" >> $BASEPATH/../log/syncRepo.log
}

# MAIN Section
[ -z "$1" ] && { usage; exit 1; };

REPOPATH="$BASEPATH/${1}"
LOCKNAME="${1}SyncRepo.lock"
LOCKFILE="$BASEPATH/$LOCKNAME"
FEDORA_REPORT_MIRROR=`which report_mirror`
REPO_PREFIX=`echo $1|awk -F'-' {'print $1'}`
RSYNC_OPTS="-4azHP --no-motd --timeout 300 --contimeout 300 --delete --delay-updates --numeric-ids --delete-delay"
WITHRSYNC=true
DELAY=0

# Clean lockfiles older than one day
# If lockfile exists, checks if associated process does too.
# If not just erase the lockfile
# If process still exists, then fails sync.
# al usar ps se escapan algunos rsync. Mejor ver si el directorio existe o no
if [ -f $LOCKFILE ]; then
    PID=`cat $LOCKFILE`
    #ps x|grep syncRepo|grep $PID > /dev/null
    if [ ! -d "/proc/$PID" ]; then
    #if [ "$?" = "1" ]; then
    echo "Removing lockfile, the associated process does not exists"
    /bin/rm -f $LOCKFILE
    else
    echo "${1} repo sync already running..."
    exit 2
    fi
fi

log "${1}_INI ${RSYNC_OPTS} ${RSYNC_SERVER} ${REPOPATH}"
#we are using shuf while syncsing all repos
#it introduces a random delay to every distro
#no need to add another DELAY
#sleep $DELAY
echo $$ > $LOCKFILE

# Start procesign repos
case "$1" in
alpine)
    RSYNC_SERVER="rsync.alpinelinux.org::alpine"
    RSYNC_OPTS="--archive --update --hard-links --delete --delete-after --delay-updates --timeout=600"
    ;;
anku)
    RSYNC_SERVER="anku.ecualinux.com::anku"
    ;;
archassault)
    RSYNC_SERVER="mirror.espoch.edu.ec::archassault"
    ;;
archlinux)
    #RSYNC_SERVER="rsync.gtlib.gatech.edu::archlinux"
    RSYNC_SERVER="mirror.us.leaseweb.net::archlinux"
    DELAY=`echo "$RANDOM/200"|bc`
    ;;
blackarch)
    #RSYNC_SERVER="mirror.team-cymru.org::blackarch"
    RSYNC_SERVER="blackarch.org::blackarch"
    ;;
calculate)
    RSYNC_SERVER="ftp.calculate-linux.ru::calculate"
    ;;
centos)
    RSYNC_OPTS="-azHP --no-motd --timeout=600 --delete --delay-updates --numeric-ids --delete-delay"
    #RSYNC_SERVER="msync.centos.org::CentOS"
    RSYNC_SERVER="mirrors.kernel.org::centos"
    ;;
centos-altarch)
    RSYNC_OPTS="-azHP --no-motd --timeout=600 --delete --delay-updates --numeric-ids --delete-delay"
    RSYNC_SERVER="msync.centos.org::altarch"
    ;;
clearlinux)
    RSYNC_SERVER="download.clearlinux.org::mirror"
    ;;
CRAN)
    RSYNC_OPTS='-e "ssh" --no-motd -rtlzv --delete'
    RSYNC_SERVER="cran-rsync@cran.r-project.org:"
    ;;
debian)
    echo "Debian está configurado con ftpsync ... descartando sync"
    /bin/rm -f $LOCKFILE
    exit 0
    ;;
debian-cd)
    #RSYNC_SERVER="mirrors.kernel.org::debian-cd"
    RSYNC_SERVER="repos.mia.lax-noc.com::debian-cd"
    RSYNC_OPTS="${RSYNC_OPTS} --times --links --hard-links --partial --block-size=8192"
    ;;
deepin)
    RSYNC_SERVER="rsync.deepin.com::deepin/"
    RSYNC_OPTS="-aP --no-motd --delete-after"
    ;;
deepin-cd)
    RSYNC_SERVER="rsync.deepin.com::deepin-cd/"
    RSYNC_OPTS="-aP --no-motd --delete-after"
    ;;
deskos)
    RSYNC_SERVER="dl.deskosproject.org::deskos"
    ;;
elrepo)
    RSYNC_SERVER="repos.mia.lax-noc.com::elrepo"
    ;;
fedora)
    WITHRSYNC=false
    log "${1}_QFM INI quick-fedora-mirror"
    $BASEPATH/../bin/quick-fedora-mirror/quick-fedora-mirror
    log "${1}_QFM END quick-fedora-mirror"
    # Since is fedora based, runs report_mirror program
    [ -n "$FEDORA_REPORT_MIRROR" ] && { log "${1}_RM INI report_mirror"; $FEDORA_REPORT_MIRROR; log "${1}_RM END report_mirror"; };
# Ya no se usa rsync directamente en favor de quick-fedora-mirror
#    #RSYNC_SERVER="mirror.uta.edu.ec::fedora"
#    RSYNC_SERVER="dl.fedoraproject.org::fedora-enchilada/linux/"
#    RSYNC_OPTS="${RSYNC_OPTS} -O --exclude-from=/var/www/etc/fedora-excluded"
#    DELAY=`echo "$RANDOM/200"|bc`
    ;;
#fedora-epel)
# quick-fedora-mirror sincroniza epel también
#    RSYNC_SERVER="dl.fedoraproject.org::fedora-epel"
#    #RSYNC_SERVER="mirror.espoch.edu.ec::fedora-epel"
#    RSYNC_OPTS="${RSYNC_OPTS} --exclude=beta/"
#    ;;
FreeBSD)
    RSYNC_SERVER="rsync.mirrorservice.org::ftp.freebsd.org/pub/FreeBSD/"
    ;;
gnu)
    RSYNC_SERVER="ftp.gnu.org::gnu"
    ;;
gnualpha)
    RSYNC_SERVER="ftp.gnu.org::alpha"
    ;;
ipfire) 
    RSYNC_SERVER="rsync.ipfire.org::full"
    #RSYNC_SERVER="mirror.uta.edu.ec::ipfire"
    ;;
kali)
    echo "Kali está configurado con ftpsync ... descartando sync"
    /bin/rm -f $LOCKFILE
    exit 0
    ;;
kali-security)
    echo "Kali Images está configurado con ftpsync ... descartando sync"
    /bin/rm -f $LOCKFILE
    exit 0
    ;;
kali-images)
    RSYNC_SERVER="archive.kali.org::kali-images"
    #RSYNC_SERVER="mirror.uta.edu.ec::kali-images"
    ;;
linux-libre)
    RSYNC_SERVER="linux-libre.fsfla.org::linux-libre"
    ;;
linuxmint)
    #RSYNC_SERVER="ftp.heanet.ie::pub/linuxmint.com/"
    RSYNC_SERVER="mirrors.kernel.org::linuxmint"
    REPOPATH="${REPOPATH}/"
    RSYNC_OPTS="${RSYNC_OPTS} --block-size=8192"
    ;;
linuxmint-packages)
    RSYNC_SERVER="rsync-packages.linuxmint.com::packages"
    ;;
manjaro)
    #RSYNC_SERVER="mirror.uta.edu.ec::manjaro"
    RSYNC_SERVER="manjaro.mirrors.uk2.net::manjaro"
    REPOPATH="$BASEPATH/${1}"
    ;;
mageia)
    RSYNC_SERVER="distrib-coffee.ipsl.jussieu.fr::mageia"
    RSYNC_OPTS="-avHS --progress --timeout=600 --delete --delay-updates --numeric-ids --delete-delay"

    ;;
mx-linux)
    export RSYNC_PASSWORD="dstuPwd"
    RSYNC_SERVER="downstreamtestuser@rsync-mxlinux.org::MX-Linux/"
    ;;
mx-workspace)
    export RSYNC_PASSWORD="T1tpw4rstmr"
    RSYNC_OPTS="-rtkv --progress --timeout=600 --delete --delay-updates --numeric-ids --delete-delay"
    RSYNC_SERVER="rsuser@iso.mxrepo.com::workspace/"
    ;;
nux-dextop)
    RSYNC_SERVER="li.nux.ro::li.nux.ro/nux/dextop/"
    REPOPATH="$BASEPATH/${1}/"
    ;;
nux-misc)
    RSYNC_SERVER="li.nux.ro::li.nux.ro/nux/misc/"
    REPOPATH="$BASEPATH/${1}/"
    ;;
nux-iso)
    RSYNC_SERVER="li.nux.ro::li.nux.ro-iso/"
    REPOPATH="$BASEPATH/${1}/"
    ;;
nongnu)
    RSYNC_SERVER="dl.sv.gnu.org::releases"
    ;;
opnsense)
    #RSYNC_SERVER="mirror.wdc1.us.leaseweb.net::opnsense"
    RSYNC_SERVER="rsync.opnsense.org::opnsense-dist"
    ;;
opensuse)
    RSYNC_OPTS="-4aHP --timeout=600 --delete --delay-updates --numeric-ids --delete-delay"
    RSYNC_SERVER="stage.opensuse.org::opensuse-full/opensuse/"
    #RSYNC_SERVER="mirrors1.kernel.org::opensuse/"
    ;;
parrot)
    RSYNC_SERVER="archive.parrotsec.org::parrot"
    ;;
pclinuxos)
    RSYNC_SERVER="mirror.uta.edu.ec::pclinuxos"
    ;;
raspbian)
    RSYNC_SERVER="archive.raspbian.org::archive"
    ;;
remi)
    wget http://rpms.famillecollet.com/index.html -O ${REPOPATH}/index.html
    DELAY=`echo "$RANDOM/400"|bc`
    RSYNC_SERVER="rpms.famillecollet.com::enterprise"
    RSYNC_SERVER1="rpms.famillecollet.com::fedora"
    REPOPATH="$BASEPATH/${1}/enterprise"
    REPOPATH1="$BASEPATH/${1}/fedora"
    ;;
linuxliteos)
    RSYNC_SERVER="repo.linuxliteos.com::repo"
    ;;
openmandriva)
    #RSYNC_SERVER="www.mirrorservice.org::downloads.openmandriva.org"
    RSYNC_SERVER="distro.ibiblio.org::openmandriva"
    ;;
rpmfusion)
    RSYNC_SERVER="download1.rpmfusion.org::rpmfusion"
    REPORT_MIRROR_CONFIG="/etc/mirrormanager-client/report_mirror-rpmfusion.conf"
    ;;
sabayon)
    RSYNC_SERVER="mirror.umd.edu::sabayonlinux"
    #RSYNC_SERVER="sabayon.c3sl.ufpr.br::sabayon"
    #RSYNC_SERVER="mirror1.mirror.garr.it::sabayonlinux"
    RSYNC_OPTS="-4aHP --timeout=600 --delete --delay-updates --numeric-ids --delete-delay"
    ;;
scientific)
    RSYNC_SERVER="mirror.lstn.net::scientific"
    ;;
slackware)
    RSYNC_SERVER="slackware.org.uk::slackware"
    ;;
tinycorelinux)
    #RSYNC_SERVER="distro.ibiblio.org::tinycorelinux"
    RSYNC_SERVER="repo.tinycorelinux.net::tc"
    ;;
tdf)
    RSYNC_SERVER="rsync.documentfoundation.org::tdf-pub"
    ;;
trisquel.packages)
    RSYNC_SERVER="rsync.trisquel.info::trisquel.packages"
    ;;
trisquel.iso)
    RSYNC_SERVER="rsync.trisquel.info::trisquel.iso"
    ;;
turnkeylinux)
    RSYNC_SERVER="mirror.turnkeylinux.org::turnkeylinux"
    ;;
ubuntu)
    echo "Ubuntu está configurado con PushMirroring ... descartando sync"
    /bin/rm -f $LOCKFILE
    exit 0
    ;;
ubuntu-releases)
    echo "Ubuntu está configurado con PushMirroring ... descartando sync"
    /bin/rm -f $LOCKFILE
    exit 0
    ;;
videolan)
    RSYNC_SERVER="ftp.belnet.be::videolan"
    ;;
zeroshell)
    RSYNC_SERVER="rsync://na.mirror.garr.it/zeroshell/"
    ;;
*)
    echo "Repo '$1' not known"
    usage
    exit 1
    ;;
esac

if $WITHRSYNC
then
    [ -d $REPOPATH ] || { mkdir -p $REPOPATH; };

    # Sync the corresponding repo
    rsync $RSYNC_OPTS $RSYNC_SERVER $REPOPATH
    
    # If repo is rpmfusion and report_mirror exists, runs report_mirror program
    [ "$1" = "rpmfusion" ] && [ -n "$FEDORA_REPORT_MIRROR" ] && { $FEDORA_REPORT_MIRROR -c $REPORT_MIRROR_CONFIG; };
    
    # If repo is ubuntu or debian let's do the second stage update required
    [ "$1" = "ubuntu" ] || [ "$1" = "debian" ] && {  log "${1}_Stage1-to-Stage2"; rsync $RSYNC_OPTS1 $RSYNC_SERVER $REPOPATH; };
    
    # If remi, we have to rsync 2 different path... here goes the second..
    [ "$1" = "remi" ] && { rsync $RSYNC_OPTS $RSYNC_SERVER1 $REPOPATH1; };
    
    # If repo is ubuntu or starts with debian, let's trace the sync
    [ "$1" = "ubuntu" ] || [ "$REPO_PREFIX" = "debian" ] && { rm -f ${REPOPATH}/project/trace/*; date -u > ${REPOPATH}/project/trace/$(hostname -f); cat ${REPOPATH}/project/trace/$(hostname -f) > ${REPOPATH}/project/trace/cdimage.debian.org; };
fi

/bin/rm -f $LOCKFILE
log "${1}_END ${RSYNC_OPTS} ${RSYNC_SERVER} ${REPOPATH}"

exit 0
